@@ -1,5 +1,6 @@
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
+from modeltrans.admin import ActiveLanguageMixin
 from mptt.admin import DraggableMPTTAdmin
 
 from flatpages_i18n.models import FlatPage_i18n, MenuItem, Menu
@@ -27,14 +28,14 @@ class MenuAdmin(admin.ModelAdmin):
 
 
 @admin.register(MenuItem)
-class MenuItemAdmin(DraggableMPTTAdmin):
-    search_fields = ('title_i18n', 'custom_link')
+class MenuItemAdmin(ActiveLanguageMixin, DraggableMPTTAdmin):
+    search_fields = ('title_i18n', 'custom_link_i18n')
     list_select_related = ['flatpage', 'menu']
     list_display = ('tree_actions', 'indented_title', 'menu', 'title_i18n', 'custom_link_i18n', 'flatpage', 'url')
     list_display_links = ('indented_title',)
     list_editable = ['menu', 'flatpage', 'title_i18n', 'custom_link_i18n']
     list_filter = ['menu']
-    fields = ['menu', 'title_i18n', 'flatpage', 'custom_link_i18n', 'target']
+    # fields = ['menu', 'title_i18n', 'flatpage', 'custom_link_i18n', 'target']
 
     def url(self, obj):
-        return obj.get_absolute_url()
\ No newline at end of file
+        return obj.get_absolute_url()
